pub struct PubSubPublish;Expand description
The publish policy for PubSubPublisher: pure declaration, constructible anywhere,
paired with the connected broker by the runtime after connect.
Examples
use ruststream_gcp_pubsub::PubSubPublish;
let policy = PubSubPublish::default();Trait Implementations
Sourceimpl Clone for PubSubPublish
impl Clone for PubSubPublish
Sourcefn clone(&self) -> PubSubPublish
fn clone(&self) -> PubSubPublish
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PubSubPublish
Sourceimpl Debug for PubSubPublish
impl Debug for PubSubPublish
Sourceimpl Default for PubSubPublish
impl Default for PubSubPublish
Sourcefn default() -> PubSubPublish
fn default() -> PubSubPublish
Returns the “default value” for a type. Read more
Sourceimpl PublishPolicy<ConnectedPubSubBroker> for PubSubPublish
impl PublishPolicy<ConnectedPubSubBroker> for PubSubPublish
Sourcetype Live = PubSubPublisher
type Live = PubSubPublisher
The live form this policy pairs into: a
Publisher for a leaf policy, or the live
wiring form for a combinator stack (a typed publisher over a policy pairs into the same
typed publisher over the live leaf).Auto Trait Implementations
impl Freeze for PubSubPublish
impl RefUnwindSafe for PubSubPublish
impl Send for PubSubPublish
impl Sync for PubSubPublish
impl Unpin for PubSubPublish
impl UnsafeUnpin for PubSubPublish
impl UnwindSafe for PubSubPublish